@@ -30,6 +30,8 @@ class ProviderModel(object):
         self.session_success = 0
         self.retry_delay = kwargs.get('retry_delay', 2)
         self.retry_when_not_found = kwargs.get('retry_when_not_found', False)
+        self.retry_time = kwargs.get('retry_time', 1)
+        self.timeout = kwargs.get('timeout', 30)
 
         self.request = kwargs.get('request', {})
         self.response = kwargs.get('response', {})
@@ -150,6 +152,9 @@ class ProviderModel(object):
     def increment_session_success(self):
         self.session_success += 1
 
+    def refresh_session_fail(self):
+        self.session_fail = 0
+
     def set_inactive(self):
         self.status = False
         # self.ssm_client.set_providers(self.to_json())
